..
 Copyright (C) 2024 Edward F. Behn, Jr.
..
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.
..
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
..
 You should have received a copy of the GNU General Public License
 along with this program.  If not, see <https://www.gnu.org/licenses/>.

Frankford
=========

**Frankford** is a Python library to use the CUDA system to fit multiple datasets simultaneously using the Levenberg–Marquardt algorithm.

.. note::

   This is a beta release that has not been completely tested.

Contents
++++++++

.. toctree::

   introduction
   overview
   basic_example
   datasets
   parameters
   fit_data
